This function calculates the average speed, polarization and shape of the group through time.
calc_global_metrics(x, geo)A dataframe with one row,
with the group metrics for that timesteps, with columns:
set, t, pol, speed, shape, N (number of individuals),
missing_ind (whether some individuals are missing).
A dataframe of a timestep of a group.
Logical, whether positions are geographic coordinates, default = FALSE.
Marina Papadopoulou m.papadopoulou.rug@gmail.com